<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="40"/>
        <source>About</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>Thanks</source>
        <translation>お礼</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Help us</source>
        <translation>私達にご協力を</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="99"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>はデスクトップのスクリーンショットを手軽に取得するためのクロスプラットフォームのアプリケーションです。</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="101"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Qt で書かれた、軽くて強力なアプリケーションです。</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="33"/>
        <source>using Qt %1</source>
        <translation>Qt %1 を使用しています</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="104"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>ウェブサイト - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="107"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation>&lt;a href=%1&gt;GPL v2&lt;/a&gt; の下でライセンスされています</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="111"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Copyright &amp;copy; 2009-2013、Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="113"/>
        <source>Copyright &amp;copy; 2013-2025, LXQt team</source>
        <translation>Copyright &amp;copy; 2013-2025, LXQt team</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="120"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>あなたが望むならば、あなたは私たちに加わり私たちを助けることができます。あなたがこのアプリケーションを好きなら、あなたを招待しましょう。</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="123"/>
        <source>What you can do?</source>
        <translation>あなたは何をしますか？</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>ScreenGrab を他の言語に翻訳</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Make suggestions for next releases</source>
        <translation>次のリリースのための提案</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="128"/>
        <source>Report bugs and issues</source>
        <translation>バグや問題の報告</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="131"/>
        <source>Bug tracker</source>
        <translation>バグ・トラッカー</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source>Special thanks to:</source>
        <translation>特別な感謝:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="144"/>
        <source>for creating ScreenGrab</source>
        <translation>ScreenGrab の作成</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source>for supporting wlr screencopy protocol</source>
        <translation>wlr スクリーンコピープロトコルのサポート</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="190"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>ディレクトリ %1 は存在しません。作成しますか？</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="191"/>
        <location filename="../src/core/ui/configwidget.cpp" line="280"/>
        <source>Warning</source>
        <translation>注意</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="268"/>
        <source>Select directory</source>
        <translation>ディレクトリの選択</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="279"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>設定を既定値にリセットしますか？</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="313"/>
        <source>Example: </source>
        <translation>例: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="354"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>このキーは、ScreenGrab で既に使用されています！ 他のキーを選択して下さい。</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="372"/>
        <source>This key is not supported on your system!</source>
        <translation>このキーは、このシステムでは対応していません！</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="392"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="66"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>はデスクトップのスクリーンショットを手軽に取得するためのクロスプラットフォームのアプリケーションです。</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="70"/>
        <source>Take a fullscreen screenshot</source>
        <translation>画面全体のスクリーンショットを取得する</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="74"/>
        <source>Take a screenshot of the active window</source>
        <translation>アクティブウィンドウのスクリーンショットを取得する</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="78"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>画面の選択した範囲のスクリーンショットを取得する</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="82"/>
        <source>Run the application with a hidden main window</source>
        <translation>メインウィンドウを表示せずにアプリケーションを実行する</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="85"/>
        <source>Save screenshot and exit, without showing window</source>
        <translation>ウィンドウを表示せずにスクリーンショットを保存して終了</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="587"/>
        <source>Saved</source>
        <translation>保存完了</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="587"/>
        <source>Saved to </source>
        <translation>保存場所 </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="609"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>保存したファイルの名前をクリップボードへコピーしました</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="615"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>保存したファイルのパスをクリップボードへコピーしました</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="638"/>
        <source>Copied</source>
        <translation>コピー完了</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="638"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>スクリーンショットをクリップボードへコピーしました</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation>ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="73"/>
        <source>Screen:</source>
        <translation>スクリーン:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="105"/>
        <source>Type:</source>
        <translation>タイプ:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="115"/>
        <source>Type of screenshot</source>
        <translation>スクリーンショットの種類</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="85"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="115"/>
        <source>Full screen</source>
        <translation>画面全体</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="116"/>
        <source>Window</source>
        <translation>ウィンドウ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="86"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="117"/>
        <source>Screen area</source>
        <translation>画面の選択範囲</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="87"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="118"/>
        <source>Last selected area</source>
        <translation>最後に選択した範囲</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="144"/>
        <source>Delay:</source>
        <translation>待ち時間:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>スクリーンショットを取得する前に秒単位で待ちます</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="163"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="222"/>
        <source>Zoom area around mouse</source>
        <translation>マウスの周辺を拡大表示する</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="229"/>
        <source>No window decoration</source>
        <translation>ウィンドウの装飾(タイトル)を除く</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="236"/>
        <source>Include mouse pointer</source>
        <translation>マウスポインターを含める</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="268"/>
        <source>toolBar</source>
        <translation>ツールバー</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="44"/>
        <source>New</source>
        <translation>新規取得</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>Save</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Copy</source>
        <translation>クリップボードへコピー</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>About</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="367"/>
        <source>Screenshot </source>
        <translation>スクリーンショット </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="371"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>ダブルクリックで、スクリーンショットを外部の既定の画像ビューアーで開きます</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="380"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="549"/>
        <source>Hide</source>
        <translation>メインウィンドウを非表示にする</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="556"/>
        <source>Show</source>
        <translation>メインウィンドウを表示する</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="625"/>
        <source>%1 Files</source>
        <translation>%1 ファイル</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="647"/>
        <source>Save As...</source>
        <translation>名前を付けて保存...</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="147"/>
        <source>Click and drag to draw a rectangle,
double click or press Enter
to take a screenshot,
or press Escape to cancel.</source>
        <translation>クリックしてドラッグすると四角を描く、
ダブルクリックまたは Enter キーで
スクリーンショットを撮る、
Esc キーでキャンセル。</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="244"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>クリックしてドラッグで長方形を描き、
それから境界に合わせるには右クリックして、
ダブルクリックするか Enter キーを押して
スクリーンショットを取得します。</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="304"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 × %2 ピクセル </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>外部編集</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>編集...</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>Qt について</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="536"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="35"/>
        <source>Main</source>
        <translation>メイン</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="40"/>
        <source>Advanced</source>
        <translation>詳細</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="45"/>
        <source>System tray</source>
        <translation>システムトレイ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="50"/>
        <source>Shortcuts</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="74"/>
        <source>Default save directory</source>
        <translation>既定の保存先ディレクトリ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="80"/>
        <source>Path to default selection dir for saving</source>
        <translation>保存するための既定のディレクトリ・パスを選択して下さい</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="93"/>
        <source>Browse filesystem</source>
        <translation>ファイルシステムを参照します</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="96"/>
        <source>Browse</source>
        <translation>参照</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="106"/>
        <source>Default file</source>
        <translation>既定のファイル</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="119"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="126"/>
        <source>Default filename</source>
        <translation>既定のファイル名です</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="137"/>
        <source>Format</source>
        <translation>フォーマット</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="150"/>
        <source>Default saving image format</source>
        <translation>保存する既定の画像フォーマットです</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="169"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>保存時にファイル名をクリップボードへ</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="183"/>
        <source>Do not copy</source>
        <translation>コピーしない</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="188"/>
        <source>Copy file name only</source>
        <translation>ファイル名のみをコピー</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="193"/>
        <source>Copy full file path</source>
        <translation>フルパスをコピー</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="203"/>
        <source>Image quality</source>
        <translation>画質</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="209"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>画質 (1 = ファイルサイズ小 〜 100 = 高品質)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="274"/>
        <source>Inserting current date time into saved filename</source>
        <translation>保存するファイル名に現在の日時を挿入します</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="277"/>
        <source>Insert current date and time in file name</source>
        <translation>ファイル名に現在の日付と時刻を挿入する</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="286"/>
        <source>Template: </source>
        <translation>テンプレート: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="311"/>
        <source>Example: </source>
        <translation>例: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="321"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>スクリーンショットを自動的に保存します</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="324"/>
        <source>Autosave screenshot</source>
        <translation>スクリーンショットを自動保存する</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="336"/>
        <source>Save first screenshot</source>
        <translation>最初のスクリーンショットも保存する</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="345"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>複数の ScreenGrab を実行できるようにします</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="348"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>複数の ScreenGrab インスタンスを許可する</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="355"/>
        <source>Open in external viewer on double click</source>
        <translation>ダブルクリックで外部のビューアーを開きます</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="358"/>
        <source>Enable external viewer</source>
        <translation>外部のビューアーを有効にする</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="365"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>これをオフにすると、選択した範囲が外側の境界に合うように大きくなります</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="369"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>右クリックで選択した範囲の内側の境界に合わせる</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="376"/>
        <source>With multiple screens</source>
        <translation>複数のスクリーン</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="379"/>
        <source>Remember last selected screen in next session</source>
        <translation>最後に選択したスクリーンを次のセッションで記憶する</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="386"/>
        <source>Notify on saving and copying</source>
        <translation>保存とコピー時に通知する</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="395"/>
        <source>Duration:</source>
        <translation>間隔:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="462"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>ScreenGrab をシステムトレイに表示する</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="402"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="469"/>
        <source>Minimize to tray on click close button</source>
        <translation>閉じるボタンをクリックしてトレイに入れる</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="472"/>
        <source>Minimize to tray when closing</source>
        <translation>閉じる時にトレイに入れる</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="511"/>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="516"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="521"/>
        <source>New screen</source>
        <translation>新しい画面</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="526"/>
        <source>Save screen</source>
        <translation>画面の保存</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="531"/>
        <source>Copy screen</source>
        <translation>画面のコピー</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="541"/>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="551"/>
        <source>Selected shortcut:</source>
        <translation>ショートカットの選択:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="558"/>
        <source>Not defined</source>
        <translation>未定義</translation>
    </message>
</context>
</TS>
